@@ -340,6 +340,13 @@ sub run {
             my $second_debian =substr $second_version,length($second_upstream);
             $second_debian =~ s/-([^-]+)$/$1/ if length($second_debian) > 0;
 
+            if ($first_version =~ /((?:[~+]deb\d+u\d+|\+nmu\d+)$)/) {
+                my $expected = substr($first_version, 0, -length($1));
+                tag 'changelog-file-missing-explicit-entry',
+                  "$second_version -> $expected (missing) -> $first_version"
+                  unless $second_version eq $expected;
+            }
+
             if (    $first_upstream eq $second_upstream
                 and $entries[0]->Source eq $entries[1]->Source) {
                 if ($entries[0]->Changes
