@@ -866,6 +866,12 @@ sub check_missing_source {
         return;
     }
 
+    # As a special-case, check debian/missing-sources including symlinks, etc.
+    foreach my $ext (($file, $basename)) {
+        my $path = normalize_pkg_path("debian/missing-sources/$ext");
+        return if $path and $info->index_resolved_path($path);
+    }
+
     # try to find for each replacement
   REPLACEMENT:
     foreach my $pair (@replacementspair) {
@@ -1379,6 +1385,13 @@ sub _check_gfdl_license_problem {
         return 0;
     }
 
+    # Some upstreams have modified the text slightly, so allow some variation.
+    return 0 if $gfdlsections =~ m/\A
+                          with [ ] no [ ] invariant [ ] sections[ ]?,
+                          [ ]? no [ ] front(?:[ ]?-[ ]?|[ ])cover [ ] (?:texts)?[ ]?,?
+                          [ ]? and [ ] (?:no [ ])? back(?:[ ]?-?[ ]?|[ ])cover [ ] texts
+                          \Z/xso;
+
     # example are ok
     if (
         $contextbefore =~ m/following [ ] is [ ] an [ ] example
